@@ -14,9 +14,10 @@ import OrdinaryDiffEqCore: alg_order, alg_adaptive_order, calculate_residuals!,
 using FastBroadcast, MuladdMacro, RecursiveArrayTools
 import StaticArrays: SArray, MVector, SVector, @SVector, StaticArray, MMatrix, SA
 import OrdinaryDiffEqCore
+using DiffEqBase: DiffEqBase, value
 
 using Reexport
-@reexport using DiffEqBase
+@reexport using SciMLBase
 
 include("algorithms.jl")
 include("alg_utils.jl")
